﻿using Microsoft.Xaml.Behaviors;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace MVVMwithWPF.Behaviors
{
    internal class TextBoxBehavior : Behavior<TextBox>
    {
        public bool IsSelectAll { get; set; } = true;

        protected override void OnAttached()
        {
            if (IsSelectAll)
                AssociatedObject.GotFocus += AssociatedObject_GotFocus;

            AssociatedObject.KeyDown += AssociatedObject_KeyDown;
        }

        private void AssociatedObject_KeyDown(object sender, System.Windows.Input.KeyEventArgs e)
        {
            if (e.Key == Key.Enter && EnterCommand != null)
            {
                EnterCommand.Execute(e);
                e.Handled = true;
            }
        }

        private void AssociatedObject_GotFocus(object sender, System.Windows.RoutedEventArgs e)
        {
            Dispatcher.BeginInvoke(() =>
            {
                AssociatedObject.SelectAll();
            }, null);
        }

        protected override void OnDetaching()
        {
            if (IsSelectAll)
                AssociatedObject.GotFocus -= AssociatedObject_GotFocus;

            AssociatedObject.KeyDown -= AssociatedObject_KeyDown;
        }

        public ICommand EnterCommand
        {
            get { return (ICommand)GetValue(EnterCommandProperty); }
            set { SetValue(EnterCommandProperty, value); }
        }

        public static readonly DependencyProperty EnterCommandProperty = DependencyProperty.Register(nameof(EnterCommand), typeof(ICommand), typeof(TextBoxBehavior), new PropertyMetadata(null));
    }
}
